@@ -28,20 +28,13 @@
 
 class AiBecai : public ComputerPlayer
 {
-    Q_OBJECT
-
 public:
     explicit AiBecai(Game *game, const QString &newName, const QColor &color);
 
-    virtual void play();
+    void play() override;
 
 private:
     int getMinimumDefenceFleetSize(Planet *planet, int minimumBaseDefenceFleetSize, double averageOwnKillPercentage, double averageOwnProduction);
-
-signals:
-
-public slots:
-
 };
 
 #endif // AI_BECAI_H
