@@ -19,9 +19,7 @@
 #include "neutralplayer.h"
 #include "../game.h"
 #include "../planet.h"
-#include <QColor>
-#include <KDebug>
-#include <QApplication>
+#include <QDebug>
 
 NeutralPlayer::NeutralPlayer(Game *game) :
     Player(game, QString(), Qt::gray)
@@ -40,13 +38,13 @@ bool NeutralPlayer::isDead()
 
 void NeutralPlayer::play()
 {
-    kDebug() << "NeutralPlayer::play";
+    //qDebug() << "NeutralPlayer::play";
 
     // Go on each attack...
-    foreach (Player *player, m_game->players()) {
+    for (Player *player : m_game->players()) {
         player->resetTurnStats();
 
-        foreach (AttackFleet *fleet, player->attackList()) {
+        for (AttackFleet *fleet : player->attackList()) {
             if (m_game->doFleetArrival(fleet)) {
                 player->attackDone(fleet);
                 fleet->deleteLater();
@@ -62,8 +60,8 @@ void NeutralPlayer::play()
     }
 
     // Go over each planet, adding its ships
-    foreach (Planet *planet, m_game->map()->planets()) {
-        kDebug() << "Turn for planet " << planet->name();
+    for (Planet *planet : m_game->map()->planets()) {
+        //qDebug() << "Turn for planet " << planet->name();
         planet->turn(m_game->options());
     }
 
